@@ -23,7 +23,7 @@ class NWPDataSource(ZarrDataSource):
     Attributes:
         _data: xr.DataArray of Numerical Weather Predictions, opened by open().
             x is left-to-right.
-            y is bottom-to-top.
+            y is top-to-bottom (after reversing the `y` index in open_nwp()).
         consolidated: Whether or not the Zarr store is consolidated.
         channels: The NWP forecast parameters to load. If None then don't filter.
             See:  http://cedadocs.ceda.ac.uk/1334/1/uk_model_data_sheet_lores1.pdf
@@ -128,9 +128,14 @@ class NWPDataSource(ZarrDataSource):
         start_dt = self._get_start_dt(t0_dt)
         end_dt = self._get_end_dt(t0_dt)
 
+        # if t0_dt is not on the hour, e.g. 13.05.
+        # Then if the history_minutes is 1 hours,
+        # so start_dt will be 12.05, but we want to the 12.00 time step too
+        start_dt = start_dt.floor("H")
+
         selected_data = selected_data.sel(target_time=slice(start_dt, end_dt))
         selected_data = selected_data.rename({"target_time": "time", "variable": "channels"})
-        selected_data.data = selected_data.data.astype(np.float16)
+        selected_data.data = selected_data.data.astype(np.float32)
 
         return selected_data
 
@@ -140,6 +145,7 @@ class NWPDataSource(ZarrDataSource):
             nwp = self._open_data()
         else:
             nwp = self._data
+
         # We need to return the `target_times` (the times the NWPs are _about_).
         # The `target_time` is the `init_time` plus the forecast horizon `step`.
         # `step` is an array of timedeltas, so we can just add `init_time` to `step`.
@@ -148,6 +154,7 @@ class NWPDataSource(ZarrDataSource):
         target_times = np.unique(target_times)
         target_times = np.sort(target_times)
         target_times = pd.DatetimeIndex(target_times)
+
         return target_times
 
     @property
@@ -172,8 +179,23 @@ def open_nwp(zarr_path: str, consolidated: bool) -> xr.DataArray:
         zarr_path, engine="zarr", consolidated=consolidated, mode="r", chunks=None
     )
 
+    # Select the "UKV" DataArray from the "nwp" Dataset.
+    # "UKV" is the one and only DataArray in the Zarr Dataset.
+    # "UKV" stands for "United Kingdom Variable", and it the UK Met Office's high-res deterministic
+    # NWP for the UK.  All the NWP variables are represented in the `variable` dimension within
+    # the UKV DataArray.
     ukv = nwp["UKV"]
 
+    # Reverse `y` so it's top-to-bottom (so ZarrDataSource.get_example() works correctly!)
+    # if necessary.  Adapted from:
+    # https://stackoverflow.com/questions/54677161/xarray-reverse-an-array-along-one-coordinate
+    if ukv.y[0] < ukv.y[1]:
+        _LOG.warning(
+            "NWP y axis runs from bottom-to-top.  Will reverse y axis so it runs top-to-bottom."
+        )
+        y_reversed = ukv.y[::-1]
+        ukv = ukv.reindex(y=y_reversed)
+
     # Sanity checks.
     # If there are any duplicated init_times then drop the duplicated init_times:
     init_time = pd.DatetimeIndex(ukv["init_time"])
